from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.get_global_messages_output_format import GetGlobalMessagesOutputFormat
from ...models.get_global_messages_scopes_item import GetGlobalMessagesScopesItem
from ...models.global_message import GlobalMessage
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    language: Union[Unset, str] = UNSET,
    read: Union[Unset, bool] = UNSET,
    group: Union[Unset, list[str]] = UNSET,
    scopes: Union[Unset, list[GetGlobalMessagesScopesItem]] = UNSET,
    output_format: Union[Unset, GetGlobalMessagesOutputFormat] = UNSET,
    run_templates: Union[Unset, bool] = False,
    output_fields: Union[Unset, str] = UNSET,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["language"] = language

    params["read"] = read

    json_group: Union[Unset, list[str]] = UNSET
    if not isinstance(group, Unset):
        json_group = group

    params["group"] = json_group

    json_scopes: Union[Unset, list[str]] = UNSET
    if not isinstance(scopes, Unset):
        json_scopes = []
        for scopes_item_data in scopes:
            scopes_item = scopes_item_data.value
            json_scopes.append(scopes_item)

    params["scopes"] = json_scopes

    json_output_format: Union[Unset, str] = UNSET
    if not isinstance(output_format, Unset):
        json_output_format = output_format.value

    params["outputFormat"] = json_output_format

    params["runTemplates"] = run_templates

    params["outputFields"] = output_fields

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/messages",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[list["GlobalMessage"]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_global_message_array_item_data in _response_200:
            componentsschemas_global_message_array_item = GlobalMessage.from_dict(
                componentsschemas_global_message_array_item_data
            )

            response_200.append(componentsschemas_global_message_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["GlobalMessage"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    language: Union[Unset, str] = UNSET,
    read: Union[Unset, bool] = UNSET,
    group: Union[Unset, list[str]] = UNSET,
    scopes: Union[Unset, list[GetGlobalMessagesScopesItem]] = UNSET,
    output_format: Union[Unset, GetGlobalMessagesOutputFormat] = UNSET,
    run_templates: Union[Unset, bool] = False,
    output_fields: Union[Unset, str] = UNSET,
) -> Response[list["GlobalMessage"]]:
    """Get messages of current user

    Args:
        language (Union[Unset, str]):
        read (Union[Unset, bool]):
        group (Union[Unset, list[str]]):
        scopes (Union[Unset, list[GetGlobalMessagesScopesItem]]):
        output_format (Union[Unset, GetGlobalMessagesOutputFormat]):
        run_templates (Union[Unset, bool]):  Default: False.
        output_fields (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['GlobalMessage']]
    """

    kwargs = _get_kwargs(
        language=language,
        read=read,
        group=group,
        scopes=scopes,
        output_format=output_format,
        run_templates=run_templates,
        output_fields=output_fields,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    language: Union[Unset, str] = UNSET,
    read: Union[Unset, bool] = UNSET,
    group: Union[Unset, list[str]] = UNSET,
    scopes: Union[Unset, list[GetGlobalMessagesScopesItem]] = UNSET,
    output_format: Union[Unset, GetGlobalMessagesOutputFormat] = UNSET,
    run_templates: Union[Unset, bool] = False,
    output_fields: Union[Unset, str] = UNSET,
) -> Optional[list["GlobalMessage"]]:
    """Get messages of current user

    Args:
        language (Union[Unset, str]):
        read (Union[Unset, bool]):
        group (Union[Unset, list[str]]):
        scopes (Union[Unset, list[GetGlobalMessagesScopesItem]]):
        output_format (Union[Unset, GetGlobalMessagesOutputFormat]):
        run_templates (Union[Unset, bool]):  Default: False.
        output_fields (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['GlobalMessage']
    """

    return sync_detailed(
        client=client,
        language=language,
        read=read,
        group=group,
        scopes=scopes,
        output_format=output_format,
        run_templates=run_templates,
        output_fields=output_fields,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    language: Union[Unset, str] = UNSET,
    read: Union[Unset, bool] = UNSET,
    group: Union[Unset, list[str]] = UNSET,
    scopes: Union[Unset, list[GetGlobalMessagesScopesItem]] = UNSET,
    output_format: Union[Unset, GetGlobalMessagesOutputFormat] = UNSET,
    run_templates: Union[Unset, bool] = False,
    output_fields: Union[Unset, str] = UNSET,
) -> Response[list["GlobalMessage"]]:
    """Get messages of current user

    Args:
        language (Union[Unset, str]):
        read (Union[Unset, bool]):
        group (Union[Unset, list[str]]):
        scopes (Union[Unset, list[GetGlobalMessagesScopesItem]]):
        output_format (Union[Unset, GetGlobalMessagesOutputFormat]):
        run_templates (Union[Unset, bool]):  Default: False.
        output_fields (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['GlobalMessage']]
    """

    kwargs = _get_kwargs(
        language=language,
        read=read,
        group=group,
        scopes=scopes,
        output_format=output_format,
        run_templates=run_templates,
        output_fields=output_fields,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    language: Union[Unset, str] = UNSET,
    read: Union[Unset, bool] = UNSET,
    group: Union[Unset, list[str]] = UNSET,
    scopes: Union[Unset, list[GetGlobalMessagesScopesItem]] = UNSET,
    output_format: Union[Unset, GetGlobalMessagesOutputFormat] = UNSET,
    run_templates: Union[Unset, bool] = False,
    output_fields: Union[Unset, str] = UNSET,
) -> Optional[list["GlobalMessage"]]:
    """Get messages of current user

    Args:
        language (Union[Unset, str]):
        read (Union[Unset, bool]):
        group (Union[Unset, list[str]]):
        scopes (Union[Unset, list[GetGlobalMessagesScopesItem]]):
        output_format (Union[Unset, GetGlobalMessagesOutputFormat]):
        run_templates (Union[Unset, bool]):  Default: False.
        output_fields (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['GlobalMessage']
    """

    return (
        await asyncio_detailed(
            client=client,
            language=language,
            read=read,
            group=group,
            scopes=scopes,
            output_format=output_format,
            run_templates=run_templates,
            output_fields=output_fields,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.vuetify_dark_theme import VuetifyDarkTheme
    from ..models.vuetify_light_theme import VuetifyLightTheme


T = TypeVar("T", bound="VuetifyThemes")


@_attrs_define
class VuetifyThemes:
    """Standard themes

    Attributes:
        dark (Union[Unset, VuetifyDarkTheme]): Standard dark colors
        light (Union[Unset, VuetifyLightTheme]): Standard light colors
    """

    dark: Union[Unset, "VuetifyDarkTheme"] = UNSET
    light: Union[Unset, "VuetifyLightTheme"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        dark: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dark, Unset):
            dark = self.dark.to_dict()

        light: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.light, Unset):
            light = self.light.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if dark is not UNSET:
            field_dict["dark"] = dark
        if light is not UNSET:
            field_dict["light"] = light

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.vuetify_dark_theme import VuetifyDarkTheme
        from ..models.vuetify_light_theme import VuetifyLightTheme

        d = dict(src_dict)
        _dark = d.pop("dark", UNSET)
        dark: Union[Unset, VuetifyDarkTheme]
        if isinstance(_dark, Unset):
            dark = UNSET
        else:
            dark = VuetifyDarkTheme.from_dict(_dark)

        _light = d.pop("light", UNSET)
        light: Union[Unset, VuetifyLightTheme]
        if isinstance(_light, Unset):
            light = UNSET
        else:
            light = VuetifyLightTheme.from_dict(_light)

        vuetify_themes = cls(
            dark=dark,
            light=light,
        )

        return vuetify_themes



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="BearerToken")


@_attrs_define
class BearerToken:
    """
    Attributes:
        access_token (str):
        email (str):
    """

    access_token: str
    email: str

    def to_dict(self) -> dict[str, Any]:
        access_token = self.access_token

        email = self.email

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "access_token": access_token,
                "email": email,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        access_token = d.pop("access_token")

        email = d.pop("email")

        bearer_token = cls(
            access_token=access_token,
            email=email,
        )

        return bearer_token



""" Contains some shared types for properties """

from collections.abc import MutableMapping
from http import HTTPStatus
from typing import BinaryIO, Generic, Literal, Optional, TypeVar

from attrs import define
from httpx import HTTPError, codes


class Unset:
    def __bool__(self) -> Literal[False]:
        return False


UNSET: Unset = Unset()

FileJsonType = tuple[Optional[str], BinaryIO, Optional[str]]


@define
class File:
    """Contains information for file uploads"""

    payload: BinaryIO
    file_name: Optional[str] = None
    mime_type: Optional[str] = None

    def to_tuple(self) -> FileJsonType:
        """Return a tuple representation that httpx will accept for multipart/form-data"""
        return self.file_name, self.payload, self.mime_type


T = TypeVar("T")


@define
class Response(Generic[T]):
    """A response from an endpoint"""

    status_code: HTTPStatus
    content: bytes
    headers: MutableMapping[str, str]
    parsed: Optional[T]

    @property
    def is_informational(self) -> bool:
        """
        A property which is `True` for 1xx status codes, `False` otherwise.
        """
        return codes.is_informational(int(self.status_code))

    @property
    def is_success(self) -> bool:
        """
        A property which is `True` for 2xx status codes, `False` otherwise.
        """
        return codes.is_success(int(self.status_code))

    @property
    def is_redirect(self) -> bool:
        """
        A property which is `True` for 3xx status codes, `False` otherwise.

        Note that not all responses with a 3xx status code indicate a URL redirect.

        Use `response.has_redirect_location` to determine responses with a properly
        formed URL redirection.
        """
        return codes.is_redirect(int(self.status_code))

    @property
    def is_client_error(self) -> bool:
        """
        A property which is `True` for 4xx status codes, `False` otherwise.
        """
        return codes.is_client_error(int(self.status_code))

    @property
    def is_server_error(self) -> bool:
        """
        A property which is `True` for 5xx status codes, `False` otherwise.
        """
        return codes.is_server_error(int(self.status_code))

    @property
    def is_error(self) -> bool:
        """
        A property which is `True` for 4xx and 5xx status codes, `False` otherwise.
        """
        return codes.is_error(int(self.status_code))

    @property
    def has_redirect_location(self) -> bool:
        """
        Returns True for 3xx responses with a properly formed URL redirection,
        `False` otherwise.
        """
        return (
            self.status_code
            in (
                # 301 (Cacheable redirect. Method may change to GET.)
                codes.MOVED_PERMANENTLY,
                # 302 (Uncacheable redirect. Method may change to GET.)
                codes.FOUND,
                # 303 (Client should make a GET or HEAD request.)
                codes.SEE_OTHER,
                # 307 (Equiv. 302, but retain method)
                codes.TEMPORARY_REDIRECT,
                # 308 (Equiv. 301, but retain method)
                codes.PERMANENT_REDIRECT,
            )
            and "Location" in self.headers
        )

    def raise_for_status(self):
        """Raises :class:`HTTPError`, if one occurred."""

        http_error_msg = ""
        if isinstance(self.content, bytes):
            # We attempt to decode utf-8 first because some servers
            # choose to localize their reason strings. If the string
            # isn't utf-8, we fall back to iso-8859-1 for all other
            # encodings. (See PR #3538)
            try:
                reason = self.content.decode("utf-8")
            except UnicodeDecodeError:
                reason = self.content.decode("iso-8859-1")
        else:
            reason = self.content

        if 400 <= int(self.status_code) < 500:
            http_error_msg = "%s Client Error: %s" % (self.status_code, reason)

        elif 500 <= int(self.status_code) < 600:
            http_error_msg = "%s Server Error: %s" % (self.status_code, reason)

        if http_error_msg:
            raise HTTPError(http_error_msg)


__all__ = ["UNSET", "File", "FileJsonType", "Response", "Unset"]



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.segment import Segment


T = TypeVar("T", bound="SegmentHit")


@_attrs_define
class SegmentHit:
    """
    Attributes:
        field_id (str):
        score (float):
        segment (Segment):
    """

    field_id: str
    score: float
    segment: "Segment"

    def to_dict(self) -> dict[str, Any]:
        field_id = self.field_id

        score = self.score

        segment = self.segment.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "_id": field_id,
                "score": score,
                "segment": segment,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.segment import Segment

        d = dict(src_dict)
        field_id = d.pop("_id")

        score = d.pop("score")

        segment = Segment.from_dict(d.pop("segment"))

        segment_hit = cls(
            field_id=field_id,
            score=score,
            segment=segment,
        )

        return segment_hit



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.search_params_type import SearchParamsType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.filtering_params import FilteringParams
    from ..models.vector_params import VectorParams


T = TypeVar("T", bound="SearchParams")


@_attrs_define
class SearchParams:
    """Search parameters

    Attributes:
        advanced (Union[Unset, bool]): Full lucene syntax will be used, but syntax errors may occur (for advanced users
            only) Default: False.
        filtering (Union[Unset, FilteringParams]): Filtering parameters
        from_ (Union[Unset, int]): Offset of the first hit to be returned Default: 0.
        invert (Union[Unset, bool]): Return hits not matching the query Default: False.
        query (Union[Unset, str]): Search keywords or question
        size (Union[Unset, int]): Maximum number of hits to be returned Default: 10.
        type_ (Union[Unset, SearchParamsType]): Whether to use standard text-based, vector-based or hybrid search
            Default: SearchParamsType.TEXT.
        vector (Union[Unset, VectorParams]): Vector or hybrid search parameters
    """

    advanced: Union[Unset, bool] = False
    filtering: Union[Unset, "FilteringParams"] = UNSET
    from_: Union[Unset, int] = 0
    invert: Union[Unset, bool] = False
    query: Union[Unset, str] = UNSET
    size: Union[Unset, int] = 10
    type_: Union[Unset, SearchParamsType] = SearchParamsType.TEXT
    vector: Union[Unset, "VectorParams"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        advanced = self.advanced

        filtering: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.filtering, Unset):
            filtering = self.filtering.to_dict()

        from_ = self.from_

        invert = self.invert

        query = self.query

        size = self.size

        type_: Union[Unset, str] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        vector: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vector, Unset):
            vector = self.vector.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if advanced is not UNSET:
            field_dict["advanced"] = advanced
        if filtering is not UNSET:
            field_dict["filtering"] = filtering
        if from_ is not UNSET:
            field_dict["from"] = from_
        if invert is not UNSET:
            field_dict["invert"] = invert
        if query is not UNSET:
            field_dict["query"] = query
        if size is not UNSET:
            field_dict["size"] = size
        if type_ is not UNSET:
            field_dict["type"] = type_
        if vector is not UNSET:
            field_dict["vector"] = vector

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.filtering_params import FilteringParams
        from ..models.vector_params import VectorParams

        d = dict(src_dict)
        advanced = d.pop("advanced", UNSET)

        _filtering = d.pop("filtering", UNSET)
        filtering: Union[Unset, FilteringParams]
        if isinstance(_filtering, Unset):
            filtering = UNSET
        else:
            filtering = FilteringParams.from_dict(_filtering)

        from_ = d.pop("from", UNSET)

        invert = d.pop("invert", UNSET)

        query = d.pop("query", UNSET)

        size = d.pop("size", UNSET)

        _type_ = d.pop("type", UNSET)
        type_: Union[Unset, SearchParamsType]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = SearchParamsType(_type_)

        _vector = d.pop("vector", UNSET)
        vector: Union[Unset, VectorParams]
        if isinstance(_vector, Unset):
            vector = UNSET
        else:
            vector = VectorParams.from_dict(_vector)

        search_params = cls(
            advanced=advanced,
            filtering=filtering,
            from_=from_,
            invert=invert,
            query=query,
            size=size,
            type_=type_,
            vector=vector,
        )

        return search_params



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="MessageMark")


@_attrs_define
class MessageMark:
    """
    Attributes:
        read (bool):
    """

    read: bool

    def to_dict(self) -> dict[str, Any]:
        read = self.read

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "read": read,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        read = d.pop("read")

        message_mark = cls(
            read=read,
        )

        return message_mark



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="Annotator")


@_attrs_define
class Annotator:
    """
    Attributes:
        engine (str):
        label (str):
        name (str):
        favorite (Union[Unset, bool]):
        is_default (Union[Unset, bool]):
    """

    engine: str
    label: str
    name: str
    favorite: Union[Unset, bool] = UNSET
    is_default: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        engine = self.engine

        label = self.label

        name = self.name

        favorite = self.favorite

        is_default = self.is_default

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "engine": engine,
                "label": label,
                "name": name,
            }
        )
        if favorite is not UNSET:
            field_dict["favorite"] = favorite
        if is_default is not UNSET:
            field_dict["isDefault"] = is_default

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        engine = d.pop("engine")

        label = d.pop("label")

        name = d.pop("name")

        favorite = d.pop("favorite", UNSET)

        is_default = d.pop("isDefault", UNSET)

        annotator = cls(
            engine=engine,
            label=label,
            name=name,
            favorite=favorite,
            is_default=is_default,
        )

        return annotator



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.signin_app_bar import SigninAppBar
    from ..models.signin_card_form import SigninCardForm
    from ..models.signin_footer import SigninFooter


T = TypeVar("T", bound="SigninConfig")


@_attrs_define
class SigninConfig:
    """Signin configuration

    Attributes:
        app_bar (Union[Unset, SigninAppBar]): Top bar on signin page
        card_form (Union[Unset, SigninCardForm]): Form on signin page
        footer (Union[Unset, SigninFooter]): Bottom bar on signin page
    """

    app_bar: Union[Unset, "SigninAppBar"] = UNSET
    card_form: Union[Unset, "SigninCardForm"] = UNSET
    footer: Union[Unset, "SigninFooter"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        app_bar: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.app_bar, Unset):
            app_bar = self.app_bar.to_dict()

        card_form: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.card_form, Unset):
            card_form = self.card_form.to_dict()

        footer: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.footer, Unset):
            footer = self.footer.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app_bar is not UNSET:
            field_dict["appBar"] = app_bar
        if card_form is not UNSET:
            field_dict["cardForm"] = card_form
        if footer is not UNSET:
            field_dict["footer"] = footer

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.signin_app_bar import SigninAppBar
        from ..models.signin_card_form import SigninCardForm
        from ..models.signin_footer import SigninFooter

        d = dict(src_dict)
        _app_bar = d.pop("appBar", UNSET)
        app_bar: Union[Unset, SigninAppBar]
        if isinstance(_app_bar, Unset):
            app_bar = UNSET
        else:
            app_bar = SigninAppBar.from_dict(_app_bar)

        _card_form = d.pop("cardForm", UNSET)
        card_form: Union[Unset, SigninCardForm]
        if isinstance(_card_form, Unset):
            card_form = UNSET
        else:
            card_form = SigninCardForm.from_dict(_card_form)

        _footer = d.pop("footer", UNSET)
        footer: Union[Unset, SigninFooter]
        if isinstance(_footer, Unset):
            footer = UNSET
        else:
            footer = SigninFooter.from_dict(_footer)

        signin_config = cls(
            app_bar=app_bar,
            card_form=card_form,
            footer=footer,
        )

        return signin_config



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user_response import UserResponse


T = TypeVar("T", bound="UsersResponse")


@_attrs_define
class UsersResponse:
    """
    Attributes:
        users (Union[Unset, list['UserResponse']]):
    """

    users: Union[Unset, list["UserResponse"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        users: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.users, Unset):
            users = []
            for users_item_data in self.users:
                users_item = users_item_data.to_dict()
                users.append(users_item)

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if users is not UNSET:
            field_dict["users"] = users

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user_response import UserResponse

        d = dict(src_dict)
        users = []
        _users = d.pop("users", UNSET)
        for users_item_data in _users or []:
            users_item = UserResponse.from_dict(users_item_data)

            users.append(users_item)

        users_response = cls(
            users=users,
        )

        return users_response



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.theme_config import ThemeConfig


T = TypeVar("T", bound="NewTheme")


@_attrs_define
class NewTheme:
    """
    Attributes:
        config (ThemeConfig):
        label (str):
    """

    config: "ThemeConfig"
    label: str

    def to_dict(self) -> dict[str, Any]:
        config = self.config.to_dict()

        label = self.label

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "config": config,
                "label": label,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.theme_config import ThemeConfig

        d = dict(src_dict)
        config = ThemeConfig.from_dict(d.pop("config"))

        label = d.pop("label")

        new_theme = cls(
            config=config,
            label=label,
        )

        return new_theme



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.new_global_message_scope import NewGlobalMessageScope
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.message_audience import MessageAudience
    from ..models.new_global_message_localized import NewGlobalMessageLocalized


T = TypeVar("T", bound="NewGlobalMessage")


@_attrs_define
class NewGlobalMessage:
    """
    Attributes:
        localized (NewGlobalMessageLocalized):
        scope (NewGlobalMessageScope):
        audience (Union[Unset, MessageAudience]):
        group (Union[Unset, str]):
        index (Union[Unset, int]):
    """

    localized: "NewGlobalMessageLocalized"
    scope: NewGlobalMessageScope
    audience: Union[Unset, "MessageAudience"] = UNSET
    group: Union[Unset, str] = UNSET
    index: Union[Unset, int] = UNSET

    def to_dict(self) -> dict[str, Any]:
        localized = self.localized.to_dict()

        scope = self.scope.value

        audience: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.audience, Unset):
            audience = self.audience.to_dict()

        group = self.group

        index = self.index

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "localized": localized,
                "scope": scope,
            }
        )
        if audience is not UNSET:
            field_dict["audience"] = audience
        if group is not UNSET:
            field_dict["group"] = group
        if index is not UNSET:
            field_dict["index"] = index

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.message_audience import MessageAudience
        from ..models.new_global_message_localized import NewGlobalMessageLocalized

        d = dict(src_dict)
        localized = NewGlobalMessageLocalized.from_dict(d.pop("localized"))

        scope = NewGlobalMessageScope(d.pop("scope"))

        _audience = d.pop("audience", UNSET)
        audience: Union[Unset, MessageAudience]
        if isinstance(_audience, Unset):
            audience = UNSET
        else:
            audience = MessageAudience.from_dict(_audience)

        group = d.pop("group", UNSET)

        index = d.pop("index", UNSET)

        new_global_message = cls(
            localized=localized,
            scope=scope,
            audience=audience,
            group=group,
            index=index,
        )

        return new_global_message



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="GeneralAppBar")


@_attrs_define
class GeneralAppBar:
    """Top bar general configuration

    Attributes:
        bar_color (Union[Unset, str]):
        icon_color (Union[Unset, str]):
        logo_is_grey (Union[Unset, bool]):  Default: True.
        logo_is_white (Union[Unset, bool]):  Default: False.
        text_color (Union[Unset, str]):
    """

    bar_color: Union[Unset, str] = UNSET
    icon_color: Union[Unset, str] = UNSET
    logo_is_grey: Union[Unset, bool] = True
    logo_is_white: Union[Unset, bool] = False
    text_color: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        bar_color = self.bar_color

        icon_color = self.icon_color

        logo_is_grey = self.logo_is_grey

        logo_is_white = self.logo_is_white

        text_color = self.text_color

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if bar_color is not UNSET:
            field_dict["barColor"] = bar_color
        if icon_color is not UNSET:
            field_dict["iconColor"] = icon_color
        if logo_is_grey is not UNSET:
            field_dict["logoIsGrey"] = logo_is_grey
        if logo_is_white is not UNSET:
            field_dict["logoIsWhite"] = logo_is_white
        if text_color is not UNSET:
            field_dict["textColor"] = text_color

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        bar_color = d.pop("barColor", UNSET)

        icon_color = d.pop("iconColor", UNSET)

        logo_is_grey = d.pop("logoIsGrey", UNSET)

        logo_is_white = d.pop("logoIsWhite", UNSET)

        text_color = d.pop("textColor", UNSET)

        general_app_bar = cls(
            bar_color=bar_color,
            icon_color=icon_color,
            logo_is_grey=logo_is_grey,
            logo_is_white=logo_is_white,
            text_color=text_color,
        )

        return general_app_bar



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.general_app_bar import GeneralAppBar
    from ..models.general_footer import GeneralFooter
    from ..models.general_toolbar import GeneralToolbar


T = TypeVar("T", bound="GeneralConfig")


@_attrs_define
class GeneralConfig:
    """General configuration

    Attributes:
        app_bar (Union[Unset, GeneralAppBar]): Top bar general configuration
        bar (Union[Unset, GeneralToolbar]): Second top bar general configuration
        footer (Union[Unset, GeneralFooter]): Bottom bar general configuration
    """

    app_bar: Union[Unset, "GeneralAppBar"] = UNSET
    bar: Union[Unset, "GeneralToolbar"] = UNSET
    footer: Union[Unset, "GeneralFooter"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        app_bar: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.app_bar, Unset):
            app_bar = self.app_bar.to_dict()

        bar: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bar, Unset):
            bar = self.bar.to_dict()

        footer: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.footer, Unset):
            footer = self.footer.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app_bar is not UNSET:
            field_dict["appBar"] = app_bar
        if bar is not UNSET:
            field_dict["bar"] = bar
        if footer is not UNSET:
            field_dict["footer"] = footer

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.general_app_bar import GeneralAppBar
        from ..models.general_footer import GeneralFooter
        from ..models.general_toolbar import GeneralToolbar

        d = dict(src_dict)
        _app_bar = d.pop("appBar", UNSET)
        app_bar: Union[Unset, GeneralAppBar]
        if isinstance(_app_bar, Unset):
            app_bar = UNSET
        else:
            app_bar = GeneralAppBar.from_dict(_app_bar)

        _bar = d.pop("bar", UNSET)
        bar: Union[Unset, GeneralToolbar]
        if isinstance(_bar, Unset):
            bar = UNSET
        else:
            bar = GeneralToolbar.from_dict(_bar)

        _footer = d.pop("footer", UNSET)
        footer: Union[Unset, GeneralFooter]
        if isinstance(_footer, Unset):
            footer = UNSET
        else:
            footer = GeneralFooter.from_dict(_footer)

        general_config = cls(
            app_bar=app_bar,
            bar=bar,
            footer=footer,
        )

        return general_config



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.search_filter import SearchFilter


T = TypeVar("T", bound="FilteringParams")


@_attrs_define
class FilteringParams:
    """Filtering parameters

    Attributes:
        filters (Union[Unset, list['SearchFilter']]):
        query_filter (Union[Unset, str]): Optional Lucene query string to filter on, e.g.: '+annotations:*'
        selected_facets (Union[Unset, list[str]]):
    """

    filters: Union[Unset, list["SearchFilter"]] = UNSET
    query_filter: Union[Unset, str] = UNSET
    selected_facets: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        filters: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.filters, Unset):
            filters = []
            for filters_item_data in self.filters:
                filters_item = filters_item_data.to_dict()
                filters.append(filters_item)

        query_filter = self.query_filter

        selected_facets: Union[Unset, list[str]] = UNSET
        if not isinstance(self.selected_facets, Unset):
            selected_facets = self.selected_facets

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if filters is not UNSET:
            field_dict["filters"] = filters
        if query_filter is not UNSET:
            field_dict["queryFilter"] = query_filter
        if selected_facets is not UNSET:
            field_dict["selectedFacets"] = selected_facets

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.search_filter import SearchFilter

        d = dict(src_dict)
        filters = []
        _filters = d.pop("filters", UNSET)
        for filters_item_data in _filters or []:
            filters_item = SearchFilter.from_dict(filters_item_data)

            filters.append(filters_item)

        query_filter = d.pop("queryFilter", UNSET)

        selected_facets = cast(list[str], d.pop("selectedFacets", UNSET))

        filtering_params = cls(
            filters=filters,
            query_filter=query_filter,
            selected_facets=selected_facets,
        )

        return filtering_params



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.user_group_ref import UserGroupRef


T = TypeVar("T", bound="OwnershipChange")


@_attrs_define
class OwnershipChange:
    """
    Attributes:
        from_ (UserGroupRef):
        project_name (str):
        to (UserGroupRef):
    """

    from_: "UserGroupRef"
    project_name: str
    to: "UserGroupRef"

    def to_dict(self) -> dict[str, Any]:
        from_ = self.from_.to_dict()

        project_name = self.project_name

        to = self.to.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "from": from_,
                "projectName": project_name,
                "to": to,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user_group_ref import UserGroupRef

        d = dict(src_dict)
        from_ = UserGroupRef.from_dict(d.pop("from"))

        project_name = d.pop("projectName")

        to = UserGroupRef.from_dict(d.pop("to"))

        ownership_change = cls(
            from_=from_,
            project_name=project_name,
            to=to,
        )

        return ownership_change



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="Credentials")


@_attrs_define
class Credentials:
    """
    Attributes:
        email (str):
        password (str):
    """

    email: str
    password: str

    def to_dict(self) -> dict[str, Any]:
        email = self.email

        password = self.password

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "email": email,
                "password": password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email")

        password = d.pop("password")

        credentials = cls(
            email=email,
            password=password,
        )

        return credentials



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.sherpa_job_bean import SherpaJobBean
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    annotator: str,
    *,
    annotator_project: Union[Unset, str] = UNSET,
    overwrite: Union[Unset, bool] = True,
    email_notification: Union[Unset, bool] = False,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["annotatorProject"] = annotator_project

    params["overwrite"] = overwrite

    params["emailNotification"] = email_notification

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_name}/annotators/{annotator}/_annotate_corpus".format(
            project_name=project_name,
            annotator=annotator,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[SherpaJobBean]:
    if response.status_code == 200:
        response_200 = SherpaJobBean.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SherpaJobBean]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    annotator: str,
    *,
    client: Union[AuthenticatedClient, Client],
    annotator_project: Union[Unset, str] = UNSET,
    overwrite: Union[Unset, bool] = True,
    email_notification: Union[Unset, bool] = False,
) -> Response[SherpaJobBean]:
    """Annotate the corpus with the given annotator

    Args:
        project_name (str):
        annotator (str):
        annotator_project (Union[Unset, str]):
        overwrite (Union[Unset, bool]):  Default: True.
        email_notification (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        annotator=annotator,
        annotator_project=annotator_project,
        overwrite=overwrite,
        email_notification=email_notification,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    annotator: str,
    *,
    client: Union[AuthenticatedClient, Client],
    annotator_project: Union[Unset, str] = UNSET,
    overwrite: Union[Unset, bool] = True,
    email_notification: Union[Unset, bool] = False,
) -> Optional[SherpaJobBean]:
    """Annotate the corpus with the given annotator

    Args:
        project_name (str):
        annotator (str):
        annotator_project (Union[Unset, str]):
        overwrite (Union[Unset, bool]):  Default: True.
        email_notification (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SherpaJobBean
    """

    return sync_detailed(
        project_name=project_name,
        annotator=annotator,
        client=client,
        annotator_project=annotator_project,
        overwrite=overwrite,
        email_notification=email_notification,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    annotator: str,
    *,
    client: Union[AuthenticatedClient, Client],
    annotator_project: Union[Unset, str] = UNSET,
    overwrite: Union[Unset, bool] = True,
    email_notification: Union[Unset, bool] = False,
) -> Response[SherpaJobBean]:
    """Annotate the corpus with the given annotator

    Args:
        project_name (str):
        annotator (str):
        annotator_project (Union[Unset, str]):
        overwrite (Union[Unset, bool]):  Default: True.
        email_notification (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        annotator=annotator,
        annotator_project=annotator_project,
        overwrite=overwrite,
        email_notification=email_notification,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    annotator: str,
    *,
    client: Union[AuthenticatedClient, Client],
    annotator_project: Union[Unset, str] = UNSET,
    overwrite: Union[Unset, bool] = True,
    email_notification: Union[Unset, bool] = False,
) -> Optional[SherpaJobBean]:
    """Annotate the corpus with the given annotator

    Args:
        project_name (str):
        annotator (str):
        annotator_project (Union[Unset, str]):
        overwrite (Union[Unset, bool]):  Default: True.
        email_notification (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SherpaJobBean
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            annotator=annotator,
            client=client,
            annotator_project=annotator_project,
            overwrite=overwrite,
            email_notification=email_notification,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="ClassificationConfig")


@_attrs_define
class ClassificationConfig:
    """
    Attributes:
        exclusive_classes (bool):
    """

    exclusive_classes: bool

    def to_dict(self) -> dict[str, Any]:
        exclusive_classes = self.exclusive_classes

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "exclusive_classes": exclusive_classes,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        exclusive_classes = d.pop("exclusive_classes")

        classification_config = cls(
            exclusive_classes=exclusive_classes,
        )

        return classification_config



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.share_mode import ShareMode
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    body: ShareMode,
    group_name: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    params: dict[str, Any] = {}

    params["groupName"] = group_name

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_name}/shares/groups".format(
            project_name=project_name,
        ),
        "params": params,
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == 204:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: ShareMode,
    group_name: Union[Unset, str] = UNSET,
) -> Response[Any]:
    """
    Args:
        project_name (str):
        group_name (Union[Unset, str]):
        body (ShareMode):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        body=body,
        group_name=group_name,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: ShareMode,
    group_name: Union[Unset, str] = UNSET,
) -> Response[Any]:
    """
    Args:
        project_name (str):
        group_name (Union[Unset, str]):
        body (ShareMode):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        body=body,
        group_name=group_name,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



import json
from collections.abc import Mapping
from io import BytesIO
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, File, FileJsonType, Unset

if TYPE_CHECKING:
    from ..models.convert_annotation_plan import ConvertAnnotationPlan


T = TypeVar("T", bound="AnnotateBinaryForm")


@_attrs_define
class AnnotateBinaryForm:
    """
    Attributes:
        file (Union[Unset, File]):  binary file to be converted and annotated
        plan (Union[Unset, ConvertAnnotationPlan]):
    """

    file: Union[Unset, File] = UNSET
    plan: Union[Unset, "ConvertAnnotationPlan"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        plan: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.plan, Unset):
            plan = self.plan.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file
        if plan is not UNSET:
            field_dict["plan"] = plan

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        plan: Union[Unset, tuple[None, bytes, str]] = UNSET
        if not isinstance(self.plan, Unset):
            plan = (None, json.dumps(self.plan.to_dict()).encode(), "application/json")

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file
        if plan is not UNSET:
            field_dict["plan"] = plan

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.convert_annotation_plan import ConvertAnnotationPlan

        d = dict(src_dict)
        _file = d.pop("file", UNSET)
        file: Union[Unset, File]
        if isinstance(_file, Unset):
            file = UNSET
        else:
            file = File(payload=BytesIO(_file))

        _plan = d.pop("plan", UNSET)
        plan: Union[Unset, ConvertAnnotationPlan]
        if isinstance(_plan, Unset):
            plan = UNSET
        else:
            plan = ConvertAnnotationPlan.from_dict(_plan)

        annotate_binary_form = cls(
            file=file,
            plan=plan,
        )

        return annotate_binary_form



import json
from collections.abc import Mapping
from io import BytesIO
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, File, FileJsonType, Unset

if TYPE_CHECKING:
    from ..models.theme_update import ThemeUpdate


T = TypeVar("T", bound="UpdateThemeForm")


@_attrs_define
class UpdateThemeForm:
    """
    Attributes:
        app_bar_image (Union[Unset, File]):  logo image
        bg_image (Union[Unset, File]):  background image
        bg_video (Union[Unset, File]):  background video
        theme (Union[Unset, ThemeUpdate]):
    """

    app_bar_image: Union[Unset, File] = UNSET
    bg_image: Union[Unset, File] = UNSET
    bg_video: Union[Unset, File] = UNSET
    theme: Union[Unset, "ThemeUpdate"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        app_bar_image: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.app_bar_image, Unset):
            app_bar_image = self.app_bar_image.to_tuple()

        bg_image: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.bg_image, Unset):
            bg_image = self.bg_image.to_tuple()

        bg_video: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.bg_video, Unset):
            bg_video = self.bg_video.to_tuple()

        theme: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.theme, Unset):
            theme = self.theme.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app_bar_image is not UNSET:
            field_dict["appBarImage"] = app_bar_image
        if bg_image is not UNSET:
            field_dict["bgImage"] = bg_image
        if bg_video is not UNSET:
            field_dict["bgVideo"] = bg_video
        if theme is not UNSET:
            field_dict["theme"] = theme

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        app_bar_image: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.app_bar_image, Unset):
            app_bar_image = self.app_bar_image.to_tuple()

        bg_image: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.bg_image, Unset):
            bg_image = self.bg_image.to_tuple()

        bg_video: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.bg_video, Unset):
            bg_video = self.bg_video.to_tuple()

        theme: Union[Unset, tuple[None, bytes, str]] = UNSET
        if not isinstance(self.theme, Unset):
            theme = (
                None,
                json.dumps(self.theme.to_dict()).encode(),
                "application/json",
            )

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app_bar_image is not UNSET:
            field_dict["appBarImage"] = app_bar_image
        if bg_image is not UNSET:
            field_dict["bgImage"] = bg_image
        if bg_video is not UNSET:
            field_dict["bgVideo"] = bg_video
        if theme is not UNSET:
            field_dict["theme"] = theme

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.theme_update import ThemeUpdate

        d = dict(src_dict)
        _app_bar_image = d.pop("appBarImage", UNSET)
        app_bar_image: Union[Unset, File]
        if isinstance(_app_bar_image, Unset):
            app_bar_image = UNSET
        else:
            app_bar_image = File(payload=BytesIO(_app_bar_image))

        _bg_image = d.pop("bgImage", UNSET)
        bg_image: Union[Unset, File]
        if isinstance(_bg_image, Unset):
            bg_image = UNSET
        else:
            bg_image = File(payload=BytesIO(_bg_image))

        _bg_video = d.pop("bgVideo", UNSET)
        bg_video: Union[Unset, File]
        if isinstance(_bg_video, Unset):
            bg_video = UNSET
        else:
            bg_video = File(payload=BytesIO(_bg_video))

        _theme = d.pop("theme", UNSET)
        theme: Union[Unset, ThemeUpdate]
        if isinstance(_theme, Unset):
            theme = UNSET
        else:
            theme = ThemeUpdate.from_dict(_theme)

        update_theme_form = cls(
            app_bar_image=app_bar_image,
            bg_image=bg_image,
            bg_video=bg_video,
            theme=theme,
        )

        return update_theme_form



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="GeneralFooter")


@_attrs_define
class GeneralFooter:
    """Bottom bar general configuration

    Attributes:
        footer_color (Union[Unset, str]):
        text_color (Union[Unset, str]):
    """

    footer_color: Union[Unset, str] = UNSET
    text_color: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        footer_color = self.footer_color

        text_color = self.text_color

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if footer_color is not UNSET:
            field_dict["footerColor"] = footer_color
        if text_color is not UNSET:
            field_dict["textColor"] = text_color

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        footer_color = d.pop("footerColor", UNSET)

        text_color = d.pop("textColor", UNSET)

        general_footer = cls(
            footer_color=footer_color,
            text_color=text_color,
        )

        return general_footer



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.with_processor_condition import WithProcessorCondition
    from ..models.with_processor_parameters import WithProcessorParameters


T = TypeVar("T", bound="WithProcessor")


@_attrs_define
class WithProcessor:
    """
    Attributes:
        processor (str):
        condition (Union[Unset, WithProcessorCondition]):
        disabled (Union[Unset, bool]):
        parameters (Union[Unset, WithProcessorParameters]):
    """

    processor: str
    condition: Union[Unset, "WithProcessorCondition"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    parameters: Union[Unset, "WithProcessorParameters"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        processor = self.processor

        condition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.condition, Unset):
            condition = self.condition.to_dict()

        disabled = self.disabled

        parameters: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "processor": processor,
            }
        )
        if condition is not UNSET:
            field_dict["condition"] = condition
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if parameters is not UNSET:
            field_dict["parameters"] = parameters

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.with_processor_condition import WithProcessorCondition
        from ..models.with_processor_parameters import WithProcessorParameters

        d = dict(src_dict)
        processor = d.pop("processor")

        _condition = d.pop("condition", UNSET)
        condition: Union[Unset, WithProcessorCondition]
        if isinstance(_condition, Unset):
            condition = UNSET
        else:
            condition = WithProcessorCondition.from_dict(_condition)

        disabled = d.pop("disabled", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, WithProcessorParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = WithProcessorParameters.from_dict(_parameters)

        with_processor = cls(
            processor=processor,
            condition=condition,
            disabled=disabled,
            parameters=parameters,
        )

        return with_processor



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="SimpleUser")


@_attrs_define
class SimpleUser:
    """
    Attributes:
        profilename (str):
        username (str):
    """

    profilename: str
    username: str

    def to_dict(self) -> dict[str, Any]:
        profilename = self.profilename

        username = self.username

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "profilename": profilename,
                "username": username,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        profilename = d.pop("profilename")

        username = d.pop("username")

        simple_user = cls(
            profilename=profilename,
            username=username,
        )

        return simple_user



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

from ..models.localized_message_format import LocalizedMessageFormat
from ..models.localized_message_templating import LocalizedMessageTemplating

T = TypeVar("T", bound="LocalizedMessage")


@_attrs_define
class LocalizedMessage:
    """
    Attributes:
        body (str):
        format_ (LocalizedMessageFormat):
        templating (LocalizedMessageTemplating):
        title (str):
    """

    body: str
    format_: LocalizedMessageFormat
    templating: LocalizedMessageTemplating
    title: str

    def to_dict(self) -> dict[str, Any]:
        body = self.body

        format_ = self.format_.value

        templating = self.templating.value

        title = self.title

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "body": body,
                "format": format_,
                "templating": templating,
                "title": title,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        body = d.pop("body")

        format_ = LocalizedMessageFormat(d.pop("format"))

        templating = LocalizedMessageTemplating(d.pop("templating"))

        title = d.pop("title")

        localized_message = cls(
            body=body,
            format_=format_,
            templating=templating,
            title=title,
        )

        return localized_message



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.theme_config import ThemeConfig


T = TypeVar("T", bound="ThemeUpdate")


@_attrs_define
class ThemeUpdate:
    """
    Attributes:
        config (Union[Unset, ThemeConfig]):
        deleted_media_files (Union[Unset, list[str]]):
        label (Union[Unset, str]):
    """

    config: Union[Unset, "ThemeConfig"] = UNSET
    deleted_media_files: Union[Unset, list[str]] = UNSET
    label: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        config: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.config, Unset):
            config = self.config.to_dict()

        deleted_media_files: Union[Unset, list[str]] = UNSET
        if not isinstance(self.deleted_media_files, Unset):
            deleted_media_files = self.deleted_media_files

        label = self.label

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if config is not UNSET:
            field_dict["config"] = config
        if deleted_media_files is not UNSET:
            field_dict["deletedMediaFiles"] = deleted_media_files
        if label is not UNSET:
            field_dict["label"] = label

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.theme_config import ThemeConfig

        d = dict(src_dict)
        _config = d.pop("config", UNSET)
        config: Union[Unset, ThemeConfig]
        if isinstance(_config, Unset):
            config = UNSET
        else:
            config = ThemeConfig.from_dict(_config)

        deleted_media_files = cast(list[str], d.pop("deletedMediaFiles", UNSET))

        label = d.pop("label", UNSET)

        theme_update = cls(
            config=config,
            deleted_media_files=deleted_media_files,
            label=label,
        )

        return theme_update



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.formatter import Formatter
    from ..models.with_annotator import WithAnnotator
    from ..models.with_converter import WithConverter
    from ..models.with_language_guesser import WithLanguageGuesser
    from ..models.with_processor import WithProcessor
    from ..models.with_segmenter import WithSegmenter
    from ..models.with_vectorizer import WithVectorizer


T = TypeVar("T", bound="FormatTextWithMany")


@_attrs_define
class FormatTextWithMany:
    """
    Attributes:
        formatter (Formatter):
        pipeline (list[Union['WithAnnotator', 'WithConverter', 'WithLanguageGuesser', 'WithProcessor', 'WithSegmenter',
            'WithVectorizer']]):
        text (str):
    """

    formatter: "Formatter"
    pipeline: list[
        Union[
            "WithAnnotator",
            "WithConverter",
            "WithLanguageGuesser",
            "WithProcessor",
            "WithSegmenter",
            "WithVectorizer",
        ]
    ]
    text: str

    def to_dict(self) -> dict[str, Any]:
        from ..models.with_annotator import WithAnnotator
        from ..models.with_converter import WithConverter
        from ..models.with_language_guesser import WithLanguageGuesser
        from ..models.with_processor import WithProcessor
        from ..models.with_segmenter import WithSegmenter

        formatter = self.formatter.to_dict()

        pipeline = []
        for pipeline_item_data in self.pipeline:
            pipeline_item: dict[str, Any]
            if isinstance(pipeline_item_data, WithAnnotator):
                pipeline_item = pipeline_item_data.to_dict()
            elif isinstance(pipeline_item_data, WithProcessor):
                pipeline_item = pipeline_item_data.to_dict()
            elif isinstance(pipeline_item_data, WithLanguageGuesser):
                pipeline_item = pipeline_item_data.to_dict()
            elif isinstance(pipeline_item_data, WithSegmenter):
                pipeline_item = pipeline_item_data.to_dict()
            elif isinstance(pipeline_item_data, WithConverter):
                pipeline_item = pipeline_item_data.to_dict()
            else:
                pipeline_item = pipeline_item_data.to_dict()

            pipeline.append(pipeline_item)

        text = self.text

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "formatter": formatter,
                "pipeline": pipeline,
                "text": text,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.formatter import Formatter
        from ..models.with_annotator import WithAnnotator
        from ..models.with_converter import WithConverter
        from ..models.with_language_guesser import WithLanguageGuesser
        from ..models.with_processor import WithProcessor
        from ..models.with_segmenter import WithSegmenter
        from ..models.with_vectorizer import WithVectorizer

        d = dict(src_dict)
        formatter = Formatter.from_dict(d.pop("formatter"))

        pipeline = []
        _pipeline = d.pop("pipeline")
        for pipeline_item_data in _pipeline:

            def _parse_pipeline_item(
                data: object,
            ) -> Union[
                "WithAnnotator",
                "WithConverter",
                "WithLanguageGuesser",
                "WithProcessor",
                "WithSegmenter",
                "WithVectorizer",
            ]:
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_0 = WithAnnotator.from_dict(data)

                    return pipeline_item_type_0
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_1 = WithProcessor.from_dict(data)

                    return pipeline_item_type_1
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_2 = WithLanguageGuesser.from_dict(data)

                    return pipeline_item_type_2
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_3 = WithSegmenter.from_dict(data)

                    return pipeline_item_type_3
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    pipeline_item_type_4 = WithConverter.from_dict(data)

                    return pipeline_item_type_4
                except:  # noqa: E722
                    pass
                if not isinstance(data, dict):
                    raise TypeError()
                pipeline_item_type_5 = WithVectorizer.from_dict(data)

                return pipeline_item_type_5

            pipeline_item = _parse_pipeline_item(pipeline_item_data)

            pipeline.append(pipeline_item)

        text = d.pop("text")

        format_text_with_many = cls(
            formatter=formatter,
            pipeline=pipeline,
            text=text,
        )

        return format_text_with_many



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserProfileUpdate")


@_attrs_define
class UserProfileUpdate:
    """
    Attributes:
        email (Union[Unset, str]):
        password (Union[Unset, str]):
        profilename (Union[Unset, str]):
    """

    email: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    profilename: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        email = self.email

        password = self.password

        profilename = self.profilename

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if email is not UNSET:
            field_dict["email"] = email
        if password is not UNSET:
            field_dict["password"] = password
        if profilename is not UNSET:
            field_dict["profilename"] = profilename

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email", UNSET)

        password = d.pop("password", UNSET)

        profilename = d.pop("profilename", UNSET)

        user_profile_update = cls(
            email=email,
            password=password,
            profilename=profilename,
        )

        return user_profile_update



from enum import Enum


class QuestionAnsweringParamsLanguageDetection(str, Enum):
    BROWSER = "browser"
    FIRST_HIT = "first_hit"
    INTERFACE = "interface"
    PROJECT = "project"
    SPECIFIC = "specific"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.batch_chown_chmod_migration import BatchChownChmodMigration
    from ..models.batch_chown_chmod_virtual_target_users_item import (
        BatchChownChmodVirtualTargetUsersItem,
    )


T = TypeVar("T", bound="BatchChownChmod")


@_attrs_define
class BatchChownChmod:
    """
    Attributes:
        migration (BatchChownChmodMigration):
        virtual_target_users (Union[Unset, list['BatchChownChmodVirtualTargetUsersItem']]):
        virtual_target_users_from_migration (Union[Unset, bool]):  Default: False.
        warn_non_chowned_projects (Union[Unset, bool]):  Default: False.
    """

    migration: "BatchChownChmodMigration"
    virtual_target_users: Union[
        Unset, list["BatchChownChmodVirtualTargetUsersItem"]
    ] = UNSET
    virtual_target_users_from_migration: Union[Unset, bool] = False
    warn_non_chowned_projects: Union[Unset, bool] = False

    def to_dict(self) -> dict[str, Any]:
        migration = self.migration.to_dict()

        virtual_target_users: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.virtual_target_users, Unset):
            virtual_target_users = []
            for virtual_target_users_item_data in self.virtual_target_users:
                virtual_target_users_item = virtual_target_users_item_data.to_dict()
                virtual_target_users.append(virtual_target_users_item)

        virtual_target_users_from_migration = self.virtual_target_users_from_migration

        warn_non_chowned_projects = self.warn_non_chowned_projects

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "migration": migration,
            }
        )
        if virtual_target_users is not UNSET:
            field_dict["virtualTargetUsers"] = virtual_target_users
        if virtual_target_users_from_migration is not UNSET:
            field_dict[
                "virtualTargetUsersFromMigration"
            ] = virtual_target_users_from_migration
        if warn_non_chowned_projects is not UNSET:
            field_dict["warnNonChownedProjects"] = warn_non_chowned_projects

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.batch_chown_chmod_migration import BatchChownChmodMigration
        from ..models.batch_chown_chmod_virtual_target_users_item import (
            BatchChownChmodVirtualTargetUsersItem,
        )

        d = dict(src_dict)
        migration = BatchChownChmodMigration.from_dict(d.pop("migration"))

        virtual_target_users = []
        _virtual_target_users = d.pop("virtualTargetUsers", UNSET)
        for virtual_target_users_item_data in _virtual_target_users or []:
            virtual_target_users_item = BatchChownChmodVirtualTargetUsersItem.from_dict(
                virtual_target_users_item_data
            )

            virtual_target_users.append(virtual_target_users_item)

        virtual_target_users_from_migration = d.pop(
            "virtualTargetUsersFromMigration", UNSET
        )

        warn_non_chowned_projects = d.pop("warnNonChownedProjects", UNSET)

        batch_chown_chmod = cls(
            migration=migration,
            virtual_target_users=virtual_target_users,
            virtual_target_users_from_migration=virtual_target_users_from_migration,
            warn_non_chowned_projects=warn_non_chowned_projects,
        )

        return batch_chown_chmod



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.classification_options import ClassificationOptions


T = TypeVar("T", bound="ConfigPatchOptions")


@_attrs_define
class ConfigPatchOptions:
    """
    Attributes:
        classification (Union[Unset, ClassificationOptions]):
        clean_html (Union[Unset, bool]):
        collaborative_annotation (Union[Unset, bool]):
        created_date (Union[Unset, str]):
        description (Union[Unset, str]):
        image_filename (Union[Unset, str]):
        image_id (Union[Unset, str]):
        image_url (Union[Unset, str]):
        label (Union[Unset, str]):
        markdown_content (Union[Unset, bool]):
        metafacets (Union[Unset, list[str]]):
        replace_carriage_returns (Union[Unset, bool]):
        route_on_open_project (Union[Unset, str]):
    """

    classification: Union[Unset, "ClassificationOptions"] = UNSET
    clean_html: Union[Unset, bool] = UNSET
    collaborative_annotation: Union[Unset, bool] = UNSET
    created_date: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    image_filename: Union[Unset, str] = UNSET
    image_id: Union[Unset, str] = UNSET
    image_url: Union[Unset, str] = UNSET
    label: Union[Unset, str] = UNSET
    markdown_content: Union[Unset, bool] = UNSET
    metafacets: Union[Unset, list[str]] = UNSET
    replace_carriage_returns: Union[Unset, bool] = UNSET
    route_on_open_project: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        classification: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.classification, Unset):
            classification = self.classification.to_dict()

        clean_html = self.clean_html

        collaborative_annotation = self.collaborative_annotation

        created_date = self.created_date

        description = self.description

        image_filename = self.image_filename

        image_id = self.image_id

        image_url = self.image_url

        label = self.label

        markdown_content = self.markdown_content

        metafacets: Union[Unset, list[str]] = UNSET
        if not isinstance(self.metafacets, Unset):
            metafacets = self.metafacets

        replace_carriage_returns = self.replace_carriage_returns

        route_on_open_project = self.route_on_open_project

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if classification is not UNSET:
            field_dict["classification"] = classification
        if clean_html is not UNSET:
            field_dict["cleanHtml"] = clean_html
        if collaborative_annotation is not UNSET:
            field_dict["collaborativeAnnotation"] = collaborative_annotation
        if created_date is not UNSET:
            field_dict["createdDate"] = created_date
        if description is not UNSET:
            field_dict["description"] = description
        if image_filename is not UNSET:
            field_dict["imageFilename"] = image_filename
        if image_id is not UNSET:
            field_dict["imageId"] = image_id
        if image_url is not UNSET:
            field_dict["imageUrl"] = image_url
        if label is not UNSET:
            field_dict["label"] = label
        if markdown_content is not UNSET:
            field_dict["markdownContent"] = markdown_content
        if metafacets is not UNSET:
            field_dict["metafacets"] = metafacets
        if replace_carriage_returns is not UNSET:
            field_dict["replaceCarriageReturns"] = replace_carriage_returns
        if route_on_open_project is not UNSET:
            field_dict["routeOnOpenProject"] = route_on_open_project

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.classification_options import ClassificationOptions

        d = dict(src_dict)
        _classification = d.pop("classification", UNSET)
        classification: Union[Unset, ClassificationOptions]
        if isinstance(_classification, Unset):
            classification = UNSET
        else:
            classification = ClassificationOptions.from_dict(_classification)

        clean_html = d.pop("cleanHtml", UNSET)

        collaborative_annotation = d.pop("collaborativeAnnotation", UNSET)

        created_date = d.pop("createdDate", UNSET)

        description = d.pop("description", UNSET)

        image_filename = d.pop("imageFilename", UNSET)

        image_id = d.pop("imageId", UNSET)

        image_url = d.pop("imageUrl", UNSET)

        label = d.pop("label", UNSET)

        markdown_content = d.pop("markdownContent", UNSET)

        metafacets = cast(list[str], d.pop("metafacets", UNSET))

        replace_carriage_returns = d.pop("replaceCarriageReturns", UNSET)

        route_on_open_project = d.pop("routeOnOpenProject", UNSET)

        config_patch_options = cls(
            classification=classification,
            clean_html=clean_html,
            collaborative_annotation=collaborative_annotation,
            created_date=created_date,
            description=description,
            image_filename=image_filename,
            image_id=image_id,
            image_url=image_url,
            label=label,
            markdown_content=markdown_content,
            metafacets=metafacets,
            replace_carriage_returns=replace_carriage_returns,
            route_on_open_project=route_on_open_project,
        )

        return config_patch_options



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.sherpa_job_bean import SherpaJobBean


T = TypeVar("T", bound="PlanOperationResponse")


@_attrs_define
class PlanOperationResponse:
    """
    Attributes:
        name (str):
        triggered_jobs (list['SherpaJobBean']):
    """

    name: str
    triggered_jobs: list["SherpaJobBean"]

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        triggered_jobs = []
        for triggered_jobs_item_data in self.triggered_jobs:
            triggered_jobs_item = triggered_jobs_item_data.to_dict()
            triggered_jobs.append(triggered_jobs_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "triggeredJobs": triggered_jobs,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sherpa_job_bean import SherpaJobBean

        d = dict(src_dict)
        name = d.pop("name")

        triggered_jobs = []
        _triggered_jobs = d.pop("triggeredJobs")
        for triggered_jobs_item_data in _triggered_jobs:
            triggered_jobs_item = SherpaJobBean.from_dict(triggered_jobs_item_data)

            triggered_jobs.append(triggered_jobs_item)

        plan_operation_response = cls(
            name=name,
            triggered_jobs=triggered_jobs,
        )

        return plan_operation_response



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.apply_to import ApplyTo
    from ..models.with_segmenter_condition import WithSegmenterCondition
    from ..models.with_segmenter_parameters import WithSegmenterParameters


T = TypeVar("T", bound="WithSegmenter")


@_attrs_define
class WithSegmenter:
    """
    Attributes:
        segmenter (str):
        apply_to (Union[Unset, ApplyTo]):
        condition (Union[Unset, WithSegmenterCondition]):
        disabled (Union[Unset, bool]):
        parameters (Union[Unset, WithSegmenterParameters]):
        project_name (Union[Unset, str]):
    """

    segmenter: str
    apply_to: Union[Unset, "ApplyTo"] = UNSET
    condition: Union[Unset, "WithSegmenterCondition"] = UNSET
    disabled: Union[Unset, bool] = UNSET
    parameters: Union[Unset, "WithSegmenterParameters"] = UNSET
    project_name: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        segmenter = self.segmenter

        apply_to: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.apply_to, Unset):
            apply_to = self.apply_to.to_dict()

        condition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.condition, Unset):
            condition = self.condition.to_dict()

        disabled = self.disabled

        parameters: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        project_name = self.project_name

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "segmenter": segmenter,
            }
        )
        if apply_to is not UNSET:
            field_dict["applyTo"] = apply_to
        if condition is not UNSET:
            field_dict["condition"] = condition
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if project_name is not UNSET:
            field_dict["projectName"] = project_name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.apply_to import ApplyTo
        from ..models.with_segmenter_condition import WithSegmenterCondition
        from ..models.with_segmenter_parameters import WithSegmenterParameters

        d = dict(src_dict)
        segmenter = d.pop("segmenter")

        _apply_to = d.pop("applyTo", UNSET)
        apply_to: Union[Unset, ApplyTo]
        if isinstance(_apply_to, Unset):
            apply_to = UNSET
        else:
            apply_to = ApplyTo.from_dict(_apply_to)

        _condition = d.pop("condition", UNSET)
        condition: Union[Unset, WithSegmenterCondition]
        if isinstance(_condition, Unset):
            condition = UNSET
        else:
            condition = WithSegmenterCondition.from_dict(_condition)

        disabled = d.pop("disabled", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, WithSegmenterParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = WithSegmenterParameters.from_dict(_parameters)

        project_name = d.pop("projectName", UNSET)

        with_segmenter = cls(
            segmenter=segmenter,
            apply_to=apply_to,
            condition=condition,
            disabled=disabled,
            parameters=parameters,
            project_name=project_name,
        )

        return with_segmenter



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.global_message_patch_scope import GlobalMessagePatchScope
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.global_message_patch_localized import GlobalMessagePatchLocalized
    from ..models.message_audience import MessageAudience


T = TypeVar("T", bound="GlobalMessagePatch")


@_attrs_define
class GlobalMessagePatch:
    """
    Attributes:
        audience (Union[Unset, MessageAudience]):
        group (Union[Unset, str]):
        index (Union[Unset, int]):
        localized (Union[Unset, GlobalMessagePatchLocalized]):
        scope (Union[Unset, GlobalMessagePatchScope]):
    """

    audience: Union[Unset, "MessageAudience"] = UNSET
    group: Union[Unset, str] = UNSET
    index: Union[Unset, int] = UNSET
    localized: Union[Unset, "GlobalMessagePatchLocalized"] = UNSET
    scope: Union[Unset, GlobalMessagePatchScope] = UNSET

    def to_dict(self) -> dict[str, Any]:
        audience: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.audience, Unset):
            audience = self.audience.to_dict()

        group = self.group

        index = self.index

        localized: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.localized, Unset):
            localized = self.localized.to_dict()

        scope: Union[Unset, str] = UNSET
        if not isinstance(self.scope, Unset):
            scope = self.scope.value

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if audience is not UNSET:
            field_dict["audience"] = audience
        if group is not UNSET:
            field_dict["group"] = group
        if index is not UNSET:
            field_dict["index"] = index
        if localized is not UNSET:
            field_dict["localized"] = localized
        if scope is not UNSET:
            field_dict["scope"] = scope

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.global_message_patch_localized import GlobalMessagePatchLocalized
        from ..models.message_audience import MessageAudience

        d = dict(src_dict)
        _audience = d.pop("audience", UNSET)
        audience: Union[Unset, MessageAudience]
        if isinstance(_audience, Unset):
            audience = UNSET
        else:
            audience = MessageAudience.from_dict(_audience)

        group = d.pop("group", UNSET)

        index = d.pop("index", UNSET)

        _localized = d.pop("localized", UNSET)
        localized: Union[Unset, GlobalMessagePatchLocalized]
        if isinstance(_localized, Unset):
            localized = UNSET
        else:
            localized = GlobalMessagePatchLocalized.from_dict(_localized)

        _scope = d.pop("scope", UNSET)
        scope: Union[Unset, GlobalMessagePatchScope]
        if isinstance(_scope, Unset):
            scope = UNSET
        else:
            scope = GlobalMessagePatchScope(_scope)

        global_message_patch = cls(
            audience=audience,
            group=group,
            index=index,
            localized=localized,
            scope=scope,
        )

        return global_message_patch



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.global_message_scope import GlobalMessageScope
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.global_message_localized import GlobalMessageLocalized
    from ..models.message_audience import MessageAudience
    from ..models.message_mark import MessageMark


T = TypeVar("T", bound="GlobalMessage")


@_attrs_define
class GlobalMessage:
    """
    Attributes:
        id (str):
        localized (GlobalMessageLocalized):
        scope (GlobalMessageScope):
        audience (Union[Unset, MessageAudience]):
        group (Union[Unset, str]):
        index (Union[Unset, int]):
        mark (Union[Unset, MessageMark]):
    """

    id: str
    localized: "GlobalMessageLocalized"
    scope: GlobalMessageScope
    audience: Union[Unset, "MessageAudience"] = UNSET
    group: Union[Unset, str] = UNSET
    index: Union[Unset, int] = UNSET
    mark: Union[Unset, "MessageMark"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        localized = self.localized.to_dict()

        scope = self.scope.value

        audience: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.audience, Unset):
            audience = self.audience.to_dict()

        group = self.group

        index = self.index

        mark: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mark, Unset):
            mark = self.mark.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "id": id,
                "localized": localized,
                "scope": scope,
            }
        )
        if audience is not UNSET:
            field_dict["audience"] = audience
        if group is not UNSET:
            field_dict["group"] = group
        if index is not UNSET:
            field_dict["index"] = index
        if mark is not UNSET:
            field_dict["mark"] = mark

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.global_message_localized import GlobalMessageLocalized
        from ..models.message_audience import MessageAudience
        from ..models.message_mark import MessageMark

        d = dict(src_dict)
        id = d.pop("id")

        localized = GlobalMessageLocalized.from_dict(d.pop("localized"))

        scope = GlobalMessageScope(d.pop("scope"))

        _audience = d.pop("audience", UNSET)
        audience: Union[Unset, MessageAudience]
        if isinstance(_audience, Unset):
            audience = UNSET
        else:
            audience = MessageAudience.from_dict(_audience)

        group = d.pop("group", UNSET)

        index = d.pop("index", UNSET)

        _mark = d.pop("mark", UNSET)
        mark: Union[Unset, MessageMark]
        if isinstance(_mark, Unset):
            mark = UNSET
        else:
            mark = MessageMark.from_dict(_mark)

        global_message = cls(
            id=id,
            localized=localized,
            scope=scope,
            audience=audience,
            group=group,
            index=index,
            mark=mark,
        )

        return global_message



from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define

T = TypeVar("T", bound="ExternalResources")


@_attrs_define
class ExternalResources:
    """
    Attributes:
        databases (list[str]):
        indexes (list[str]):
    """

    databases: list[str]
    indexes: list[str]

    def to_dict(self) -> dict[str, Any]:
        databases = self.databases

        indexes = self.indexes

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "databases": databases,
                "indexes": indexes,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        databases = cast(list[str], d.pop("databases"))

        indexes = cast(list[str], d.pop("indexes"))

        external_resources = cls(
            databases=databases,
            indexes=indexes,
        )

        return external_resources



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.new_gazetteer_parameters import NewGazetteerParameters


T = TypeVar("T", bound="NewGazetteer")


@_attrs_define
class NewGazetteer:
    """
    Attributes:
        engine (str):
        label (str):
        parameters (NewGazetteerParameters):
        email_notification (Union[Unset, bool]):
        tags (Union[Unset, list[str]]):
    """

    engine: str
    label: str
    parameters: "NewGazetteerParameters"
    email_notification: Union[Unset, bool] = UNSET
    tags: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        engine = self.engine

        label = self.label

        parameters = self.parameters.to_dict()

        email_notification = self.email_notification

        tags: Union[Unset, list[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "engine": engine,
                "label": label,
                "parameters": parameters,
            }
        )
        if email_notification is not UNSET:
            field_dict["emailNotification"] = email_notification
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.new_gazetteer_parameters import NewGazetteerParameters

        d = dict(src_dict)
        engine = d.pop("engine")

        label = d.pop("label")

        parameters = NewGazetteerParameters.from_dict(d.pop("parameters"))

        email_notification = d.pop("emailNotification", UNSET)

        tags = cast(list[str], d.pop("tags", UNSET))

        new_gazetteer = cls(
            engine=engine,
            label=label,
            parameters=parameters,
            email_notification=email_notification,
            tags=tags,
        )

        return new_gazetteer



from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.user_response import UserResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    username: str,
    *,
    admin_data: Union[Unset, bool] = True,
    jwt_format: Union[Unset, bool] = False,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["adminData"] = admin_data

    params["jwtFormat"] = jwt_format

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/users/{username}".format(
            username=username,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, UserResponse]]:
    if response.status_code == 200:
        response_200 = UserResponse.from_dict(response.json())

        return response_200
    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, UserResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    username: str,
    *,
    client: Union[AuthenticatedClient, Client],
    admin_data: Union[Unset, bool] = True,
    jwt_format: Union[Unset, bool] = False,
) -> Response[Union[Any, UserResponse]]:
    """Get user

    Args:
        username (str):
        admin_data (Union[Unset, bool]):  Default: True.
        jwt_format (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, UserResponse]]
    """

    kwargs = _get_kwargs(
        username=username,
        admin_data=admin_data,
        jwt_format=jwt_format,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    username: str,
    *,
    client: Union[AuthenticatedClient, Client],
    admin_data: Union[Unset, bool] = True,
    jwt_format: Union[Unset, bool] = False,
) -> Optional[Union[Any, UserResponse]]:
    """Get user

    Args:
        username (str):
        admin_data (Union[Unset, bool]):  Default: True.
        jwt_format (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, UserResponse]
    """

    return sync_detailed(
        username=username,
        client=client,
        admin_data=admin_data,
        jwt_format=jwt_format,
    ).parsed


async def asyncio_detailed(
    username: str,
    *,
    client: Union[AuthenticatedClient, Client],
    admin_data: Union[Unset, bool] = True,
    jwt_format: Union[Unset, bool] = False,
) -> Response[Union[Any, UserResponse]]:
    """Get user

    Args:
        username (str):
        admin_data (Union[Unset, bool]):  Default: True.
        jwt_format (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, UserResponse]]
    """

    kwargs = _get_kwargs(
        username=username,
        admin_data=admin_data,
        jwt_format=jwt_format,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    username: str,
    *,
    client: Union[AuthenticatedClient, Client],
    admin_data: Union[Unset, bool] = True,
    jwt_format: Union[Unset, bool] = False,
) -> Optional[Union[Any, UserResponse]]:
    """Get user

    Args:
        username (str):
        admin_data (Union[Unset, bool]):  Default: True.
        jwt_format (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, UserResponse]
    """

    return (
        await asyncio_detailed(
            username=username,
            client=client,
            admin_data=admin_data,
            jwt_format=jwt_format,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.simple_group_desc_mapping_discriminator import (
    SimpleGroupDescMappingDiscriminator,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="SimpleGroupDesc")


@_attrs_define
class SimpleGroupDesc:
    """
    Attributes:
        label (str):
        name (str):
        identifier (Union[Unset, str]):
        mapping_discriminator (Union[Unset, SimpleGroupDescMappingDiscriminator]):
    """

    label: str
    name: str
    identifier: Union[Unset, str] = UNSET
    mapping_discriminator: Union[Unset, SimpleGroupDescMappingDiscriminator] = UNSET

    def to_dict(self) -> dict[str, Any]:
        label = self.label

        name = self.name

        identifier = self.identifier

        mapping_discriminator: Union[Unset, str] = UNSET
        if not isinstance(self.mapping_discriminator, Unset):
            mapping_discriminator = self.mapping_discriminator.value

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "label": label,
                "name": name,
            }
        )
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if mapping_discriminator is not UNSET:
            field_dict["mappingDiscriminator"] = mapping_discriminator

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        label = d.pop("label")

        name = d.pop("name")

        identifier = d.pop("identifier", UNSET)

        _mapping_discriminator = d.pop("mappingDiscriminator", UNSET)
        mapping_discriminator: Union[Unset, SimpleGroupDescMappingDiscriminator]
        if isinstance(_mapping_discriminator, Unset):
            mapping_discriminator = UNSET
        else:
            mapping_discriminator = SimpleGroupDescMappingDiscriminator(
                _mapping_discriminator
            )

        simple_group_desc = cls(
            label=label,
            name=name,
            identifier=identifier,
            mapping_discriminator=mapping_discriminator,
        )

        return simple_group_desc



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.vuetify_themes import VuetifyThemes


T = TypeVar("T", bound="VuetifyConfig")


@_attrs_define
class VuetifyConfig:
    """Standard configuration

    Attributes:
        dark (Union[Unset, bool]):  Default: False.
        themes (Union[Unset, VuetifyThemes]): Standard themes
    """

    dark: Union[Unset, bool] = False
    themes: Union[Unset, "VuetifyThemes"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        dark = self.dark

        themes: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.themes, Unset):
            themes = self.themes.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if dark is not UNSET:
            field_dict["dark"] = dark
        if themes is not UNSET:
            field_dict["themes"] = themes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.vuetify_themes import VuetifyThemes

        d = dict(src_dict)
        dark = d.pop("dark", UNSET)

        _themes = d.pop("themes", UNSET)
        themes: Union[Unset, VuetifyThemes]
        if isinstance(_themes, Unset):
            themes = UNSET
        else:
            themes = VuetifyThemes.from_dict(_themes)

        vuetify_config = cls(
            dark=dark,
            themes=themes,
        )

        return vuetify_config



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="EngineConfig")


@_attrs_define
class EngineConfig:
    """
    Attributes:
        name (str):
        type_ (str):
    """

    name: str
    type_: str

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "type": type_,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        type_ = d.pop("type")

        engine_config = cls(
            name=name,
            type_=type_,
        )

        return engine_config



from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define

T = TypeVar("T", bound="BatchErrors")


@_attrs_define
class BatchErrors:
    """
    Attributes:
        missing_project (list[str]):
        missing_project_group (list[str]):
        missing_project_owner (list[str]):
    """

    missing_project: list[str]
    missing_project_group: list[str]
    missing_project_owner: list[str]

    def to_dict(self) -> dict[str, Any]:
        missing_project = self.missing_project

        missing_project_group = self.missing_project_group

        missing_project_owner = self.missing_project_owner

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "missingProject": missing_project,
                "missingProjectGroup": missing_project_group,
                "missingProjectOwner": missing_project_owner,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        missing_project = cast(list[str], d.pop("missingProject"))

        missing_project_group = cast(list[str], d.pop("missingProjectGroup"))

        missing_project_owner = cast(list[str], d.pop("missingProjectOwner"))

        batch_errors = cls(
            missing_project=missing_project,
            missing_project_group=missing_project_group,
            missing_project_owner=missing_project_owner,
        )

        return batch_errors



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="Bucket")


@_attrs_define
class Bucket:
    """
    Attributes:
        doc_count (int):
        key (str):
    """

    doc_count: int
    key: str

    def to_dict(self) -> dict[str, Any]:
        doc_count = self.doc_count

        key = self.key

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "doc_count": doc_count,
                "key": key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        doc_count = d.pop("doc_count")

        key = d.pop("key")

        bucket = cls(
            doc_count=doc_count,
            key=key,
        )

        return bucket



from enum import Enum


class GetGlobalMessagesScopesItem(str, Enum):
    CLASSIFY_QUESTION = "classify_question"
    LOGIN = "login"
    SEARCH_DOCUMENTS = "search_documents"
    SYSTEM_PROMPT = "system_prompt"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.search_filter_filter_selector import SearchFilterFilterSelector
from ..models.search_filter_filter_type import SearchFilterFilterType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchFilter")


@_attrs_define
class SearchFilter:
    """
    Attributes:
        field (Union[Unset, str]):  Default: 'text'.
        filter_selector (Union[Unset, SearchFilterFilterSelector]):  Default: SearchFilterFilterSelector.MUST.
        filter_type (Union[Unset, SearchFilterFilterType]):  Default: SearchFilterFilterType.QUERY.
        value (Union[Unset, str]): offset from the first result you want to fetch Default: ''.
    """

    field: Union[Unset, str] = "text"
    filter_selector: Union[
        Unset, SearchFilterFilterSelector
    ] = SearchFilterFilterSelector.MUST
    filter_type: Union[Unset, SearchFilterFilterType] = SearchFilterFilterType.QUERY
    value: Union[Unset, str] = ""

    def to_dict(self) -> dict[str, Any]:
        field = self.field

        filter_selector: Union[Unset, str] = UNSET
        if not isinstance(self.filter_selector, Unset):
            filter_selector = self.filter_selector.value

        filter_type: Union[Unset, str] = UNSET
        if not isinstance(self.filter_type, Unset):
            filter_type = self.filter_type.value

        value = self.value

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if field is not UNSET:
            field_dict["field"] = field
        if filter_selector is not UNSET:
            field_dict["filterSelector"] = filter_selector
        if filter_type is not UNSET:
            field_dict["filterType"] = filter_type
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        field = d.pop("field", UNSET)

        _filter_selector = d.pop("filterSelector", UNSET)
        filter_selector: Union[Unset, SearchFilterFilterSelector]
        if isinstance(_filter_selector, Unset):
            filter_selector = UNSET
        else:
            filter_selector = SearchFilterFilterSelector(_filter_selector)

        _filter_type = d.pop("filterType", UNSET)
        filter_type: Union[Unset, SearchFilterFilterType]
        if isinstance(_filter_type, Unset):
            filter_type = UNSET
        else:
            filter_type = SearchFilterFilterType(_filter_type)

        value = d.pop("value", UNSET)

        search_filter = cls(
            field=field,
            filter_selector=filter_selector,
            filter_type=filter_type,
            value=value,
        )

        return search_filter



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.vector_params_native_rrf import VectorParamsNativeRRF
from ..types import UNSET, Unset

T = TypeVar("T", bound="VectorParams")


@_attrs_define
class VectorParams:
    """Vector or hybrid search parameters

    Attributes:
        native_rrf (Union[Unset, VectorParamsNativeRRF]): Use native RRF implementation (for hybrid search) Default:
            VectorParamsNativeRRF.IF_AVAILABLE.
        query (Union[Unset, str]): Sentence or question to be vectorized (if it must be different from the general
            query; if not defined, the general query is used)
        vectorizer (Union[Unset, str]): Vectorizer to be used in case of vector-based or hybrid search (name of a
            vectorization pipeline)
    """

    native_rrf: Union[Unset, VectorParamsNativeRRF] = VectorParamsNativeRRF.IF_AVAILABLE
    query: Union[Unset, str] = UNSET
    vectorizer: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        native_rrf: Union[Unset, str] = UNSET
        if not isinstance(self.native_rrf, Unset):
            native_rrf = self.native_rrf.value

        query = self.query

        vectorizer = self.vectorizer

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if native_rrf is not UNSET:
            field_dict["nativeRRF"] = native_rrf
        if query is not UNSET:
            field_dict["query"] = query
        if vectorizer is not UNSET:
            field_dict["vectorizer"] = vectorizer

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _native_rrf = d.pop("nativeRRF", UNSET)
        native_rrf: Union[Unset, VectorParamsNativeRRF]
        if isinstance(_native_rrf, Unset):
            native_rrf = UNSET
        else:
            native_rrf = VectorParamsNativeRRF(_native_rrf)

        query = d.pop("query", UNSET)

        vectorizer = d.pop("vectorizer", UNSET)

        vector_params = cls(
            native_rrf=native_rrf,
            query=query,
            vectorizer=vectorizer,
        )

        return vector_params



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="BatchMigrationReceive")


@_attrs_define
class BatchMigrationReceive:
    """
    Attributes:
        ownership (Union[Unset, list[str]]):
        read_access (Union[Unset, list[str]]):
        write_access (Union[Unset, list[str]]):
    """

    ownership: Union[Unset, list[str]] = UNSET
    read_access: Union[Unset, list[str]] = UNSET
    write_access: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        ownership: Union[Unset, list[str]] = UNSET
        if not isinstance(self.ownership, Unset):
            ownership = self.ownership

        read_access: Union[Unset, list[str]] = UNSET
        if not isinstance(self.read_access, Unset):
            read_access = self.read_access

        write_access: Union[Unset, list[str]] = UNSET
        if not isinstance(self.write_access, Unset):
            write_access = self.write_access

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if ownership is not UNSET:
            field_dict["ownership"] = ownership
        if read_access is not UNSET:
            field_dict["readAccess"] = read_access
        if write_access is not UNSET:
            field_dict["writeAccess"] = write_access

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        ownership = cast(list[str], d.pop("ownership", UNSET))

        read_access = cast(list[str], d.pop("readAccess", UNSET))

        write_access = cast(list[str], d.pop("writeAccess", UNSET))

        batch_migration_receive = cls(
            ownership=ownership,
            read_access=read_access,
            write_access=write_access,
        )

        return batch_migration_receive



""" A client library for accessing Sherpa API documentation """
from .client import ApiKeyAuth, AuthenticatedClient, BearerAuth, Client

__all__ = (
    "AuthenticatedClient",
    "Client",
    "ApiKeyAuth",
    "BearerAuth",
)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.app_config import AppConfig
    from ..models.vuetify_config import VuetifyConfig


T = TypeVar("T", bound="ThemeConfig")


@_attrs_define
class ThemeConfig:
    """
    Attributes:
        app (Union[Unset, AppConfig]):
        vuetify (Union[Unset, VuetifyConfig]): Standard configuration
    """

    app: Union[Unset, "AppConfig"] = UNSET
    vuetify: Union[Unset, "VuetifyConfig"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        app: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.app, Unset):
            app = self.app.to_dict()

        vuetify: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vuetify, Unset):
            vuetify = self.vuetify.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app is not UNSET:
            field_dict["app"] = app
        if vuetify is not UNSET:
            field_dict["vuetify"] = vuetify

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.app_config import AppConfig
        from ..models.vuetify_config import VuetifyConfig

        d = dict(src_dict)
        _app = d.pop("app", UNSET)
        app: Union[Unset, AppConfig]
        if isinstance(_app, Unset):
            app = UNSET
        else:
            app = AppConfig.from_dict(_app)

        _vuetify = d.pop("vuetify", UNSET)
        vuetify: Union[Unset, VuetifyConfig]
        if isinstance(_vuetify, Unset):
            vuetify = UNSET
        else:
            vuetify = VuetifyConfig.from_dict(_vuetify)

        theme_config = cls(
            app=app,
            vuetify=vuetify,
        )

        return theme_config



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.imported_document import ImportedDocument
from ...models.launch_json_documents_import_clean_text import (
    LaunchJsonDocumentsImportCleanText,
)
from ...models.launch_json_documents_import_segmentation_policy import (
    LaunchJsonDocumentsImportSegmentationPolicy,
)
from ...models.sherpa_job_bean import SherpaJobBean
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    body: list["ImportedDocument"],
    ignore_labelling: Union[Unset, bool] = False,
    segmentation_policy: Union[
        Unset, LaunchJsonDocumentsImportSegmentationPolicy
    ] = LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, bool] = False,
    clean_text: Union[
        Unset, LaunchJsonDocumentsImportCleanText
    ] = LaunchJsonDocumentsImportCleanText.DEFAULT,
    group_name: Union[Unset, str] = UNSET,
    idp_group_identifier: Union[Unset, str] = UNSET,
    wait: Union[Unset, bool] = False,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    params: dict[str, Any] = {}

    params["ignoreLabelling"] = ignore_labelling

    json_segmentation_policy: Union[Unset, str] = UNSET
    if not isinstance(segmentation_policy, Unset):
        json_segmentation_policy = segmentation_policy.value

    params["segmentationPolicy"] = json_segmentation_policy

    params["splitCorpus"] = split_corpus

    json_clean_text: Union[Unset, str] = UNSET
    if not isinstance(clean_text, Unset):
        json_clean_text = clean_text.value

    params["cleanText"] = json_clean_text

    params["groupName"] = group_name

    params["idpGroupIdentifier"] = idp_group_identifier

    params["wait"] = wait

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_name}/documents/_import_documents".format(
            project_name=project_name,
        ),
        "params": params,
    }

    _body = []
    for componentsschemas_imported_document_array_item_data in body:
        componentsschemas_imported_document_array_item = (
            componentsschemas_imported_document_array_item_data.to_dict()
        )
        _body.append(componentsschemas_imported_document_array_item)

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[SherpaJobBean]:
    if response.status_code == 200:
        response_200 = SherpaJobBean.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SherpaJobBean]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: list["ImportedDocument"],
    ignore_labelling: Union[Unset, bool] = False,
    segmentation_policy: Union[
        Unset, LaunchJsonDocumentsImportSegmentationPolicy
    ] = LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, bool] = False,
    clean_text: Union[
        Unset, LaunchJsonDocumentsImportCleanText
    ] = LaunchJsonDocumentsImportCleanText.DEFAULT,
    group_name: Union[Unset, str] = UNSET,
    idp_group_identifier: Union[Unset, str] = UNSET,
    wait: Union[Unset, bool] = False,
) -> Response[SherpaJobBean]:
    """upload documents and launch a job to add them into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, bool]):  Default: False.
        segmentation_policy (Union[Unset, LaunchJsonDocumentsImportSegmentationPolicy]):  Default:
            LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, bool]):  Default: False.
        clean_text (Union[Unset, LaunchJsonDocumentsImportCleanText]):  Default:
            LaunchJsonDocumentsImportCleanText.DEFAULT.
        group_name (Union[Unset, str]):
        idp_group_identifier (Union[Unset, str]):
        wait (Union[Unset, bool]):  Default: False.
        body (list['ImportedDocument']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        body=body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        group_name=group_name,
        idp_group_identifier=idp_group_identifier,
        wait=wait,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: list["ImportedDocument"],
    ignore_labelling: Union[Unset, bool] = False,
    segmentation_policy: Union[
        Unset, LaunchJsonDocumentsImportSegmentationPolicy
    ] = LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, bool] = False,
    clean_text: Union[
        Unset, LaunchJsonDocumentsImportCleanText
    ] = LaunchJsonDocumentsImportCleanText.DEFAULT,
    group_name: Union[Unset, str] = UNSET,
    idp_group_identifier: Union[Unset, str] = UNSET,
    wait: Union[Unset, bool] = False,
) -> Optional[SherpaJobBean]:
    """upload documents and launch a job to add them into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, bool]):  Default: False.
        segmentation_policy (Union[Unset, LaunchJsonDocumentsImportSegmentationPolicy]):  Default:
            LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, bool]):  Default: False.
        clean_text (Union[Unset, LaunchJsonDocumentsImportCleanText]):  Default:
            LaunchJsonDocumentsImportCleanText.DEFAULT.
        group_name (Union[Unset, str]):
        idp_group_identifier (Union[Unset, str]):
        wait (Union[Unset, bool]):  Default: False.
        body (list['ImportedDocument']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SherpaJobBean
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        body=body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        group_name=group_name,
        idp_group_identifier=idp_group_identifier,
        wait=wait,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: list["ImportedDocument"],
    ignore_labelling: Union[Unset, bool] = False,
    segmentation_policy: Union[
        Unset, LaunchJsonDocumentsImportSegmentationPolicy
    ] = LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, bool] = False,
    clean_text: Union[
        Unset, LaunchJsonDocumentsImportCleanText
    ] = LaunchJsonDocumentsImportCleanText.DEFAULT,
    group_name: Union[Unset, str] = UNSET,
    idp_group_identifier: Union[Unset, str] = UNSET,
    wait: Union[Unset, bool] = False,
) -> Response[SherpaJobBean]:
    """upload documents and launch a job to add them into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, bool]):  Default: False.
        segmentation_policy (Union[Unset, LaunchJsonDocumentsImportSegmentationPolicy]):  Default:
            LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, bool]):  Default: False.
        clean_text (Union[Unset, LaunchJsonDocumentsImportCleanText]):  Default:
            LaunchJsonDocumentsImportCleanText.DEFAULT.
        group_name (Union[Unset, str]):
        idp_group_identifier (Union[Unset, str]):
        wait (Union[Unset, bool]):  Default: False.
        body (list['ImportedDocument']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SherpaJobBean]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        body=body,
        ignore_labelling=ignore_labelling,
        segmentation_policy=segmentation_policy,
        split_corpus=split_corpus,
        clean_text=clean_text,
        group_name=group_name,
        idp_group_identifier=idp_group_identifier,
        wait=wait,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: list["ImportedDocument"],
    ignore_labelling: Union[Unset, bool] = False,
    segmentation_policy: Union[
        Unset, LaunchJsonDocumentsImportSegmentationPolicy
    ] = LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING,
    split_corpus: Union[Unset, bool] = False,
    clean_text: Union[
        Unset, LaunchJsonDocumentsImportCleanText
    ] = LaunchJsonDocumentsImportCleanText.DEFAULT,
    group_name: Union[Unset, str] = UNSET,
    idp_group_identifier: Union[Unset, str] = UNSET,
    wait: Union[Unset, bool] = False,
) -> Optional[SherpaJobBean]:
    """upload documents and launch a job to add them into the project

    Args:
        project_name (str):
        ignore_labelling (Union[Unset, bool]):  Default: False.
        segmentation_policy (Union[Unset, LaunchJsonDocumentsImportSegmentationPolicy]):  Default:
            LaunchJsonDocumentsImportSegmentationPolicy.COMPUTE_IF_MISSING.
        split_corpus (Union[Unset, bool]):  Default: False.
        clean_text (Union[Unset, LaunchJsonDocumentsImportCleanText]):  Default:
            LaunchJsonDocumentsImportCleanText.DEFAULT.
        group_name (Union[Unset, str]):
        idp_group_identifier (Union[Unset, str]):
        wait (Union[Unset, bool]):  Default: False.
        body (list['ImportedDocument']):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SherpaJobBean
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            body=body,
            ignore_labelling=ignore_labelling,
            segmentation_policy=segmentation_policy,
            split_corpus=split_corpus,
            clean_text=clean_text,
            group_name=group_name,
            idp_group_identifier=idp_group_identifier,
            wait=wait,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SigninCardSubtitles")


@_attrs_define
class SigninCardSubtitles:
    """Subtitles on signin page

    Attributes:
        en (Union[Unset, str]):  Default: 'AI language solutions for business users'.
        fr (Union[Unset, str]):  Default: "Solutions d'IA de traitement du langage".
    """

    en: Union[Unset, str] = "AI language solutions for business users"
    fr: Union[Unset, str] = "Solutions d'IA de traitement du langage"

    def to_dict(self) -> dict[str, Any]:
        en = self.en

        fr = self.fr

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if en is not UNSET:
            field_dict["en"] = en
        if fr is not UNSET:
            field_dict["fr"] = fr

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        en = d.pop("en", UNSET)

        fr = d.pop("fr", UNSET)

        signin_card_subtitles = cls(
            en=en,
            fr=fr,
        )

        return signin_card_subtitles



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.general_config import GeneralConfig
    from ..models.signin_config import SigninConfig
    from ..models.theme_media import ThemeMedia


T = TypeVar("T", bound="AppConfig")


@_attrs_define
class AppConfig:
    """
    Attributes:
        general (Union[Unset, GeneralConfig]): General configuration
        media (Union[Unset, ThemeMedia]): Images and videos on signin page
        signin (Union[Unset, SigninConfig]): Signin configuration
    """

    general: Union[Unset, "GeneralConfig"] = UNSET
    media: Union[Unset, "ThemeMedia"] = UNSET
    signin: Union[Unset, "SigninConfig"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        general: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.general, Unset):
            general = self.general.to_dict()

        media: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.media, Unset):
            media = self.media.to_dict()

        signin: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.signin, Unset):
            signin = self.signin.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if general is not UNSET:
            field_dict["general"] = general
        if media is not UNSET:
            field_dict["media"] = media
        if signin is not UNSET:
            field_dict["signin"] = signin

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.general_config import GeneralConfig
        from ..models.signin_config import SigninConfig
        from ..models.theme_media import ThemeMedia

        d = dict(src_dict)
        _general = d.pop("general", UNSET)
        general: Union[Unset, GeneralConfig]
        if isinstance(_general, Unset):
            general = UNSET
        else:
            general = GeneralConfig.from_dict(_general)

        _media = d.pop("media", UNSET)
        media: Union[Unset, ThemeMedia]
        if isinstance(_media, Unset):
            media = UNSET
        else:
            media = ThemeMedia.from_dict(_media)

        _signin = d.pop("signin", UNSET)
        signin: Union[Unset, SigninConfig]
        if isinstance(_signin, Unset):
            signin = UNSET
        else:
            signin = SigninConfig.from_dict(_signin)

        app_config = cls(
            general=general,
            media=media,
            signin=signin,
        )

        return app_config



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.search_segments_search_type import SearchSegmentsSearchType
from ...models.segment_hits import SegmentHits
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    query: Union[Unset, str] = "",
    from_: Union[Unset, int] = 0,
    size: Union[Unset, int] = 10,
    highlight: Union[Unset, bool] = False,
    facet: Union[Unset, bool] = False,
    query_filter: Union[Unset, str] = "",
    output_fields: Union[Unset, str] = "",
    simple_query: Union[Unset, bool] = False,
    selected_facets: Union[Unset, list[str]] = UNSET,
    invert_search: Union[Unset, bool] = False,
    search_type: Union[Unset, SearchSegmentsSearchType] = SearchSegmentsSearchType.TEXT,
    native_rrf: Union[Unset, bool] = UNSET,
    vectorizer: Union[Unset, str] = UNSET,
    vector_query: Union[Unset, str] = "",
    answer_question: Union[Unset, bool] = False,
    answerer: Union[Unset, str] = UNSET,
    return_hits: Union[Unset, bool] = True,
    html_version: Union[Unset, bool] = False,
    async_answer: Union[Unset, bool] = False,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["query"] = query

    params["from"] = from_

    params["size"] = size

    params["highlight"] = highlight

    params["facet"] = facet

    params["queryFilter"] = query_filter

    params["outputFields"] = output_fields

    params["simpleQuery"] = simple_query

    json_selected_facets: Union[Unset, list[str]] = UNSET
    if not isinstance(selected_facets, Unset):
        json_selected_facets = selected_facets

    params["selectedFacets"] = json_selected_facets

    params["invertSearch"] = invert_search

    json_search_type: Union[Unset, str] = UNSET
    if not isinstance(search_type, Unset):
        json_search_type = search_type.value

    params["searchType"] = json_search_type

    params["nativeRRF"] = native_rrf

    params["vectorizer"] = vectorizer

    params["vectorQuery"] = vector_query

    params["answerQuestion"] = answer_question

    params["answerer"] = answerer

    params["returnHits"] = return_hits

    params["htmlVersion"] = html_version

    params["asyncAnswer"] = async_answer

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_name}/segments/_search".format(
            project_name=project_name,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[SegmentHits]:
    if response.status_code == 200:
        response_200 = SegmentHits.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[SegmentHits]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    query: Union[Unset, str] = "",
    from_: Union[Unset, int] = 0,
    size: Union[Unset, int] = 10,
    highlight: Union[Unset, bool] = False,
    facet: Union[Unset, bool] = False,
    query_filter: Union[Unset, str] = "",
    output_fields: Union[Unset, str] = "",
    simple_query: Union[Unset, bool] = False,
    selected_facets: Union[Unset, list[str]] = UNSET,
    invert_search: Union[Unset, bool] = False,
    search_type: Union[Unset, SearchSegmentsSearchType] = SearchSegmentsSearchType.TEXT,
    native_rrf: Union[Unset, bool] = UNSET,
    vectorizer: Union[Unset, str] = UNSET,
    vector_query: Union[Unset, str] = "",
    answer_question: Union[Unset, bool] = False,
    answerer: Union[Unset, str] = UNSET,
    return_hits: Union[Unset, bool] = True,
    html_version: Union[Unset, bool] = False,
    async_answer: Union[Unset, bool] = False,
) -> Response[SegmentHits]:
    """Search for segments

    Args:
        project_name (str):
        query (Union[Unset, str]):  Default: ''.
        from_ (Union[Unset, int]):  Default: 0.
        size (Union[Unset, int]):  Default: 10.
        highlight (Union[Unset, bool]):  Default: False.
        facet (Union[Unset, bool]):  Default: False.
        query_filter (Union[Unset, str]):  Default: ''.
        output_fields (Union[Unset, str]):  Default: ''.
        simple_query (Union[Unset, bool]):  Default: False.
        selected_facets (Union[Unset, list[str]]):
        invert_search (Union[Unset, bool]):  Default: False.
        search_type (Union[Unset, SearchSegmentsSearchType]):  Default:
            SearchSegmentsSearchType.TEXT.
        native_rrf (Union[Unset, bool]):
        vectorizer (Union[Unset, str]):
        vector_query (Union[Unset, str]):  Default: ''.
        answer_question (Union[Unset, bool]):  Default: False.
        answerer (Union[Unset, str]):
        return_hits (Union[Unset, bool]):  Default: True.
        html_version (Union[Unset, bool]):  Default: False.
        async_answer (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        query=query,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        invert_search=invert_search,
        search_type=search_type,
        native_rrf=native_rrf,
        vectorizer=vectorizer,
        vector_query=vector_query,
        answer_question=answer_question,
        answerer=answerer,
        return_hits=return_hits,
        html_version=html_version,
        async_answer=async_answer,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    query: Union[Unset, str] = "",
    from_: Union[Unset, int] = 0,
    size: Union[Unset, int] = 10,
    highlight: Union[Unset, bool] = False,
    facet: Union[Unset, bool] = False,
    query_filter: Union[Unset, str] = "",
    output_fields: Union[Unset, str] = "",
    simple_query: Union[Unset, bool] = False,
    selected_facets: Union[Unset, list[str]] = UNSET,
    invert_search: Union[Unset, bool] = False,
    search_type: Union[Unset, SearchSegmentsSearchType] = SearchSegmentsSearchType.TEXT,
    native_rrf: Union[Unset, bool] = UNSET,
    vectorizer: Union[Unset, str] = UNSET,
    vector_query: Union[Unset, str] = "",
    answer_question: Union[Unset, bool] = False,
    answerer: Union[Unset, str] = UNSET,
    return_hits: Union[Unset, bool] = True,
    html_version: Union[Unset, bool] = False,
    async_answer: Union[Unset, bool] = False,
) -> Optional[SegmentHits]:
    """Search for segments

    Args:
        project_name (str):
        query (Union[Unset, str]):  Default: ''.
        from_ (Union[Unset, int]):  Default: 0.
        size (Union[Unset, int]):  Default: 10.
        highlight (Union[Unset, bool]):  Default: False.
        facet (Union[Unset, bool]):  Default: False.
        query_filter (Union[Unset, str]):  Default: ''.
        output_fields (Union[Unset, str]):  Default: ''.
        simple_query (Union[Unset, bool]):  Default: False.
        selected_facets (Union[Unset, list[str]]):
        invert_search (Union[Unset, bool]):  Default: False.
        search_type (Union[Unset, SearchSegmentsSearchType]):  Default:
            SearchSegmentsSearchType.TEXT.
        native_rrf (Union[Unset, bool]):
        vectorizer (Union[Unset, str]):
        vector_query (Union[Unset, str]):  Default: ''.
        answer_question (Union[Unset, bool]):  Default: False.
        answerer (Union[Unset, str]):
        return_hits (Union[Unset, bool]):  Default: True.
        html_version (Union[Unset, bool]):  Default: False.
        async_answer (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SegmentHits
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        query=query,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        invert_search=invert_search,
        search_type=search_type,
        native_rrf=native_rrf,
        vectorizer=vectorizer,
        vector_query=vector_query,
        answer_question=answer_question,
        answerer=answerer,
        return_hits=return_hits,
        html_version=html_version,
        async_answer=async_answer,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    query: Union[Unset, str] = "",
    from_: Union[Unset, int] = 0,
    size: Union[Unset, int] = 10,
    highlight: Union[Unset, bool] = False,
    facet: Union[Unset, bool] = False,
    query_filter: Union[Unset, str] = "",
    output_fields: Union[Unset, str] = "",
    simple_query: Union[Unset, bool] = False,
    selected_facets: Union[Unset, list[str]] = UNSET,
    invert_search: Union[Unset, bool] = False,
    search_type: Union[Unset, SearchSegmentsSearchType] = SearchSegmentsSearchType.TEXT,
    native_rrf: Union[Unset, bool] = UNSET,
    vectorizer: Union[Unset, str] = UNSET,
    vector_query: Union[Unset, str] = "",
    answer_question: Union[Unset, bool] = False,
    answerer: Union[Unset, str] = UNSET,
    return_hits: Union[Unset, bool] = True,
    html_version: Union[Unset, bool] = False,
    async_answer: Union[Unset, bool] = False,
) -> Response[SegmentHits]:
    """Search for segments

    Args:
        project_name (str):
        query (Union[Unset, str]):  Default: ''.
        from_ (Union[Unset, int]):  Default: 0.
        size (Union[Unset, int]):  Default: 10.
        highlight (Union[Unset, bool]):  Default: False.
        facet (Union[Unset, bool]):  Default: False.
        query_filter (Union[Unset, str]):  Default: ''.
        output_fields (Union[Unset, str]):  Default: ''.
        simple_query (Union[Unset, bool]):  Default: False.
        selected_facets (Union[Unset, list[str]]):
        invert_search (Union[Unset, bool]):  Default: False.
        search_type (Union[Unset, SearchSegmentsSearchType]):  Default:
            SearchSegmentsSearchType.TEXT.
        native_rrf (Union[Unset, bool]):
        vectorizer (Union[Unset, str]):
        vector_query (Union[Unset, str]):  Default: ''.
        answer_question (Union[Unset, bool]):  Default: False.
        answerer (Union[Unset, str]):
        return_hits (Union[Unset, bool]):  Default: True.
        html_version (Union[Unset, bool]):  Default: False.
        async_answer (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SegmentHits]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        query=query,
        from_=from_,
        size=size,
        highlight=highlight,
        facet=facet,
        query_filter=query_filter,
        output_fields=output_fields,
        simple_query=simple_query,
        selected_facets=selected_facets,
        invert_search=invert_search,
        search_type=search_type,
        native_rrf=native_rrf,
        vectorizer=vectorizer,
        vector_query=vector_query,
        answer_question=answer_question,
        answerer=answerer,
        return_hits=return_hits,
        html_version=html_version,
        async_answer=async_answer,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    query: Union[Unset, str] = "",
    from_: Union[Unset, int] = 0,
    size: Union[Unset, int] = 10,
    highlight: Union[Unset, bool] = False,
    facet: Union[Unset, bool] = False,
    query_filter: Union[Unset, str] = "",
    output_fields: Union[Unset, str] = "",
    simple_query: Union[Unset, bool] = False,
    selected_facets: Union[Unset, list[str]] = UNSET,
    invert_search: Union[Unset, bool] = False,
    search_type: Union[Unset, SearchSegmentsSearchType] = SearchSegmentsSearchType.TEXT,
    native_rrf: Union[Unset, bool] = UNSET,
    vectorizer: Union[Unset, str] = UNSET,
    vector_query: Union[Unset, str] = "",
    answer_question: Union[Unset, bool] = False,
    answerer: Union[Unset, str] = UNSET,
    return_hits: Union[Unset, bool] = True,
    html_version: Union[Unset, bool] = False,
    async_answer: Union[Unset, bool] = False,
) -> Optional[SegmentHits]:
    """Search for segments

    Args:
        project_name (str):
        query (Union[Unset, str]):  Default: ''.
        from_ (Union[Unset, int]):  Default: 0.
        size (Union[Unset, int]):  Default: 10.
        highlight (Union[Unset, bool]):  Default: False.
        facet (Union[Unset, bool]):  Default: False.
        query_filter (Union[Unset, str]):  Default: ''.
        output_fields (Union[Unset, str]):  Default: ''.
        simple_query (Union[Unset, bool]):  Default: False.
        selected_facets (Union[Unset, list[str]]):
        invert_search (Union[Unset, bool]):  Default: False.
        search_type (Union[Unset, SearchSegmentsSearchType]):  Default:
            SearchSegmentsSearchType.TEXT.
        native_rrf (Union[Unset, bool]):
        vectorizer (Union[Unset, str]):
        vector_query (Union[Unset, str]):  Default: ''.
        answer_question (Union[Unset, bool]):  Default: False.
        answerer (Union[Unset, str]):
        return_hits (Union[Unset, bool]):  Default: True.
        html_version (Union[Unset, bool]):  Default: False.
        async_answer (Union[Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SegmentHits
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            query=query,
            from_=from_,
            size=size,
            highlight=highlight,
            facet=facet,
            query_filter=query_filter,
            output_fields=output_fields,
            simple_query=simple_query,
            selected_facets=selected_facets,
            invert_search=invert_search,
            search_type=search_type,
            native_rrf=native_rrf,
            vectorizer=vectorizer,
            vector_query=vector_query,
            answer_question=answer_question,
            answerer=answerer,
            return_hits=return_hits,
            html_version=html_version,
            async_answer=async_answer,
        )
    ).parsed
